;********************************************************************
;AV5H.ASM
;CPU and specific includes for AVISE Forth Interpreter, Suboutine-threaded.
;16 Bit Stack, 16 Bit Token
;*********************************************************************
; Attention: r0,r1 have double function, risk of reentrance
; r0 reserved for EEPROM,LPM,SPM and temporarily used in diverse helper functions
; r1 is used to burn Flash (SPM) and temporarily used in diverse helper functions

.def    SAVE_SREG      	=r2   	;temporary storage in interrupt routines

.def    TEMP3           =r3   	;local and temporary parameter transfer
.def    TEMP4           =r4   	;local and temporary parameter transfer
.def    TEMP5           =r5   	;temporary as Token-Low Byte

.def	CBUFLO			=r6		;pointer to actual CBUF operation (BYTES)
.def 	CBUFHI			=r7	
.def 	PAGELO			=r8		;pointer to start of actual Flash page (BYTES)
.def	PAGEHI			=r9		;COPLO,COPHI is pointer to actual Flash op.

.def    STRSTART        =r10   	;pointer to start of scanned string
.def    STRINGLEN       =r11  	;length of scanned string

.def 	MS100CNT		=r12	;10Hz subcounter in timer0Int
.def  	LEDCNT          =r13   	;LED for data reception via terminal

.def 	WAVELOL			=r14
.def 	WAVELOH			=r15

.def    AVIFLAGS        =r16
	#define    	COMPILE      0		;0=interpreting, 1=compiling
	#define    	m_COMPILE    1
	
	#define    	NOLEADS      1		;sendASCII: set=no leading spaces
	#define    	m_NOLEADS    2

	#define    	TQUIET       2     	;if set:terminal input not responded
	#define    	m_TQUIET     4

	#define    	TEMPHEX      3     	;number base HEX only in a single action
	#define    	m_TEMPHEX    8

	#define    	HEX          4     	;set=number base HEX, cleared:set DECIMAL
	#define    	m_HEX        0x10  

	#define    	HEXBACK      5     	;reminder for Decimalflag in Compilation
	#define    	m_HEXBACK    0x20  	;set=Decimal-number base

	#define    	VREF0        6		;ADC Vref configuration
	#define    	m_VREF0      0x40	

	#define    	VREF1     	 7		
	#define    	m_VREF1   	 0x80


.def    XFLAGS          =r17     	;Xtended Flag Register
	#define    	XTIME        0
	#define    	m_XTIME      1		;adds 1/2 to timer interrupt countup

	#define    	SPIBUSY      1     	;set:SPI is active on SCK,MISO,MOSI pins
	#define    	m_SPIBUSY    2

	#define    	TIM1BUSY     2		;set Timer1 active
	#define    	m_TIM1BUSY   4

	#define    	PWMBUSY     3		;set Timer2 or Timer3(CPU 3244) PWM active
	#define    	m_PWMBUSY   8

	#define    	USART1_ON	4		;only used with ATMega 32U4, 64, 1284
	#define    	m_USART1_ON	0x10

  #if ((CPU==3244) || (CPU==644) || (CPU==1284))
	#define    	NOBACKGND    5		;if set,refuse low level backgnd messages
	#define    	m_NOBACKGND  0x20	;default=0
  #endif
  #if ((CPU != 32) && (CPU != 3244))
	#define    	HISPEED		6
	#define    	m_HISPEED	0x40
  #endif
  #if (CPU==3244)  
	#define 	LEADZERO	6
	#define 	m_LEADZERO 	0x40
	#define 	USBCONNECTED 7
	#define 	m_USBCONNECTED 0x80
  #endif

.def 	YFLAGS			=r18
#if (CPU==3244)
	#define	   	EP1TRIGGER	0	;simplifies TX buffer fill state 
	#define	   	m_EP1TRIGGER 1

	#define    	EP2LOCK		1	;protect RX buffer against overflow
	#define    	m_EP2LOCK	2

	#define	   	EP3TRIGGER	2	;only formally used for clean USB interface
	#define	   	m_EP3TRIGGER 4

	#define    	BAKDOTS		3 	;set:call background tasks 
	#define    	m_BAKDOTS	8 	;in timer0 interrupt routine
#endif

	#define		NUMVABC		4	;set: ATmega32U4:sendCmdByte without interrupt
	#define 	m_NUMVABC	0x10 ;provides more stability in some cases
								;else suppress obsolete OK messages at QUIT
	#define 	GETVABC		5	;insert background process for VA,VB,VC
	#define 	m_GETVABC	0x20

	#define 	SAVEVA		6
	#define 	m_SAVEVA	0x40

	#define 	SAVEVB		7
	#define 	m_SAVEVB	0x80

.def    TOSL            =r19
.def    TOSH            =r20  ;Top Of Stack

.def    TEMP1           =r21  ;local and temporary parameter transfer
.def    TEMP2           =r22  ;local and temporary parameter transfer
							  ;and temporary as Token-High Byte
.def    INTREG          =r23  ;reserved as TEMP register in interrupt routines

; r24 and r25 are  reserved as TEMP registers wo. special names
; as reference to manual:
;.def    XL              =r26
;.def    XH              =r27
; essentially X is reserved as DataStack pointer, sometimes used else
;.def    YL              =r28
;.def    YH              =r29
;axiliary register pair
;.def    ZL              =r30
;.def    ZH              =r31
; Z is Token Pointer, and auxiliary register pair
; SP is Returnstack Pointer

; --------------------------------------------------------------------

#if (CPU==168) ;ATTENTION: prozessor registers up to 0xFF!!
;==================
;internal system variables
#define SRAMBOT         0x100
#define TIB             0x100	;filling upwards, 86 bytes
#define TIBTOP          0x156
#define BAKTIB			0x156	;max 8 bytes
#define VA_VALUE		0x160	;word entry, little endian
#define VB_VALUE		0x162	;word entry, little endian
#define VC_VALUE		0x164	;word entry, little endian
#define VARBASE         0x166   ;all VAR values must be in the same SRAM page 
#define VARTOP          0x1A6   ;i.e. max 32 global WORD-variables, little endian
#define ARRAY			0x1A6	;data array 128 bytes =64 word entries	
#define ARRAYTOP		0x226	;filling upwards,little endian stored

;internal application process variables
#define CNT0L           0x227
#define CNT0H           0x228
#define ENC0L           0x229
#define ENC0H           0x22A
#define RANDOML			0x22B
#define RANDOMH			0x22C

;internal system variables
#define MSCNTL        	0x22D
#define MSCNTH        	0x22E
#define TIXCNTL			0x22F
#define TIXCNTH			0x230

#define WAVEHIL			0x231
#define WAVEHIH			0x232

#define LEDAUTO         0x233 	;0=LED_AUTO(default), 1=LED_OFF, 2=LED_ON
#define VARLOW          0x234   ;LowByte parameter storage of latest VAR
#define BAKTIBPTR		0x235	;pointer actual entry in BAKTIB
#define FCARRYL			0x236	;Forth Carry word (shifted,over,under)
#define FCARRYH			0x237

#define USYMBHEADL      0x238   ;count byte of latest valid entry
#define USYMBHEADH      0x238   ;updated by SEMIS, VAR, CONST
#define COPLO           0x23A   ;code compiler pointer LOW byte (BYTES)
#define COPHI           0x23B   ;code compiler pointer HIGH Byte
#define DELTACFLO       0x23C   ;Delta actual code pointer n Flash and
#define DELTACFHI       0x23D   ;it's mirror in CBUF(used by CBurn)
								;SYMP points to count byte of latest entry
#define STARTCOPL       0x23E   ;start address of actual page in Flash
#define STARTCOPH       0x23F
#define PAD             0x240	;sendWord temporary storage, filling upwards
								;max 8 bytes
#define RETURNSTACK     0x2A8   ;filling downwards, pointer=SPH,SPL,max.90 bytes
#define DATASTACK       0x2FA   ;filling downwards, 80 bytes = 40 entries

#define CMDRXHEADL      0x2FE
#define CMDRXTAILL      0x2FF

#define	INIMAX			0x300	;top of initial memory clearing

#define CMDRXBUF        0x300   ;cyclic filling upwards,256 Bytes
#define CMDRXBUFTOP     0x400

#define CBUF            0x400   ;256 bytes regulary montage buffer for Code
#define CBUFTOP         0x500 	; = 2 Flash pages
#define SRAMTOP         0x500

#endif ; (mega168)

;--------------------------------------------------------------------

#if ((CPU==328) || (CPU==32))  ;ATTENTION: prozessor registers up to 0xFF!!
;==================
;internal system variables
#define SRAMBOT         0x100
#define TIB             0x100	;filling upwards, 86 bytes
#define TIBTOP          0x156
#define BAKTIB			0x156	;max 8 bytes
#define VA_VALUE		0x160	;word entry, little endian
#define VB_VALUE		0x162	;word entry, little endian
#define VC_VALUE		0x164	;word entry, little endian
#define VARBASE         0x166   ;all VAR values must be in the same SRAM page 
#define VARTOP          0x1A6   ;i.e. max 32 global WORD-variables
#define ARRAY			0x1A6	;data array 512 bytes = 256 word entries	
#define ARRAYTOP		0x3A6	;filling upwards,little endian stored

;internal application process variables
#define CNT0L           0x3A7
#define CNT0H           0x3A8
#define ENC0L           0x3A9
#define ENC0H           0x3AA
#if (CPU==32)
#define CNTXL           0x3AB
#define CNTXH           0x3AC
#define ENCXL           0x3AD
#define ENCXH           0x3AE
#endif
#define RANDOML			0x3AF
#define RANDOMH			0x3B0

;internal system variables
#define MSCNTL        	0x3B1
#define MSCNTH        	0x3B2
#define TIXCNTL			0x3B3
#define TIXCNTH			0x3B4

#define WAVEHIL			0x3B5
#define WAVEHIH			0x3B6

#define LEDAUTO         0x3B7 	;0=LED_AUTO(default), 1=LED_OFF, 2=LED_ON
#define VARLOW          0x3B8   ;LowByte parameter storage of latest VAR
#define BAKTIBPTR		0x3B9	;pointer actual entry in BAKTIB
#define FCARRYL			0x3BA	;Forth Carry word (shifted,over,under)
#define FCARRYH			0x3BB

#define USYMBHEADL      0x3BC   ;count byte of latest valid entry
#define USYMBHEADH      0x3BD   ;updated by SEMIS, VAR, CONST
#define COPLO           0x3BE   ;code compiler pointer LOW byte
#define COPHI           0x3BF   ;code compiler pointer HIGH Byte
#define DELTACFLO       0x3C0   ;Delta actual code pointer n Flash and
#define DELTACFHI       0x3C1   ;it's mirror in CBUF(used by CBurn)
								;SYMP points to count byte of latest entry
#define STARTCOPL       0x3C2   ;start address of actual page in Flash
#define STARTCOPH       0x3C3	
#define PAD             0x3C4	;sendWord temporary storage, filling upwards
								;max 8 Bytes
#define RETURNSTACK     0x450   ;filling downwards, pointer=SPH,SPL,120 bytes
#define DATASTACK       0x4B4   ;filling downwards, 96 bytes = 48 entries
							
#define CMDRXHEADL      0x4C0
#define CMDRXTAILL      0x4C2
;intermediate range reserved
#define	INIMAX			0x500	;top of initial memory clearing

#define CMDRXBUF        0x500   ;cyclic filling upwards,256 Bytes
#define CMDRXBUFTOP     0x600

#define CBUF            0x700   ;256 bytes regulary montage buffer for Code
#define CBUFTOP         0x800 	; = 2 Flash pages
#define SRAMTOP         0x900

#endif


;--------------------------------------------------------------------

#if ((CPU==644) || (CPU==1284))  ;ATTENTION: prozessor registers up to 0xFF!!
;==================
;internal system variables
#define SRAMBOT         0x100
#define TIB             0x100	;filling upwards, 86 bytes
#define TIBTOP          0x156
#define BAKTIB			0x156	;max 8 bytes
#define VA_VALUE		0x160	;word entry, little endian
#define VB_VALUE		0x162	;word entry, little endian
#define VC_VALUE		0x164	;word entry, little endian
#define VARBASE         0x166   ;all VAR values must be in the same SRAM page 
#define VARTOP          0x1A6   ;i.e. max 32 global WORD-variables
#define ARRAY			0x1A6	;data array 512 bytes = 256 word entries	
#define ARRAYTOP		0x5A6	;filling upwards,little endian stored

;internal application process variables
#define CNT0L           0x5A7
#define CNT0H           0x5A8
#define ENC0L           0x5A9
#define ENC0H           0x5AA

#define CNTXL           0x5AB
#define CNTXH           0x5AC
#define ENCXL           0x5AD
#define ENCXH           0x5AE

#define RANDOML			0x5AF
#define RANDOMH			0x5B0

;internal system variables
#define MSCNTL        	0x5B1
#define MSCNTH        	0x5B2
#define TIXCNTL			0x5B3
#define TIXCNTH			0x5B4

#define WAVEHIL			0x5B5
#define WAVEHIH			0x5B6  

#define LEDAUTO         0x5B7 	;0=LED_AUTO(default), 1=LED_OFF, 2=LED_ON
#define VARLOW          0x5B8   ;LowByte parameter storage of latest VAR
#define BAKTIBPTR		0x5B9	;pointer actual entry in BAKTIB
#define FCARRYL			0x5BA	;Forth Carry word (shifted,over,under)
#define FCARRYH			0x5BB

#define USYMBHEADL      0x5BC   ;count byte of latest valid entry
#define USYMBHEADH      0x5BD   ;updated by SEMIS, VAR, CONST
#define COPLO           0x5BE   ;code compiler pointer LOW byte
#define COPHI           0x5BF   ;code compiler pointer HIGH Byte
#define DELTACFLO       0x5C0   ;Delta actual code pointer n Flash and
#define DELTACFHI       0x5C1   ;it's mirror in CBUF(used by CBurn)
								;SYMP points to count byte of latest entry
#define STARTCOPL       0x5C2   ;start address of actual page in Flash
#define STARTCOPH       0x5C3
#define PAD             0x5C4	;sendWord temporary storage, filling upwards
								;max 8 bytes
#define RETURNSTACK     0x658   ;filling downwards, pointer=SPH,SPL,128 bytes
#define DATASTACK       0x6C0   ;filling downwards, 96 bytes = 48entries

#define CMDRXHEADL      0x6D0
#define CMDRXTAILL      0x6D1
#define US1RXHEAD       0x6D2
#define US1RXTAIL       0x6D3
;intermediate range reserved
#define	INIMAX			0x700	;top of initial memory clearing

#define CMDRXBUF        0x700   ;cyclic filling upwards,256 Bytes
#define CMDRXBUFTOP     0x800
#define US1RXBUF        0x800   ;cyclic filling upwards,256 Bytes
#define US1RXBUFTOP     0x900

#define CBUF            0x900   ;512 bytes regulary montage buffer for Code
#define CBUFTOP         0xB00 ; = 2 Flash pages

#define SRAMTOP         0x1100

#endif

;--------------------------------------------------------------------
#if (CPU==3244)  	;ATTENTION: prozessor registers up to 0xFF!!
;==================
;internal system variables
#define SRAMBOT         0x100
#define TIB             0x100	;filling upwards, 86 bytes
#define TIBTOP          0x156
#define BAKTIB			0x156	;max 8 bytes
#define VA_VALUE		0x160	;word entry, little endian
#define VB_VALUE		0x162	;word entry, little endian
#define VC_VALUE		0x164	;word entry, little endian
#define VARBASE         0x166   ;all VAR values must be in the same SRAM page 
#define VARTOP          0x1A6   ;i.e. max 32 global WORD-variables
#define ARRAY			0x1A6	;data array 512 bytes = 256 word entries	
#define ARRAYTOP		0x3A6	;filling upwards,little endian stored

;internal application process variables
#define CNT0L           0x3A7
#define CNT0H           0x3A8
#define ENC0L           0x3A9
#define ENC0H           0x3AA

#define CNTXL           0x3AB
#define CNTXH           0x3AC
#define ENCXL           0x3AD
#define ENCXH           0x3AE

#define RANDOML			0x3AF
#define RANDOMH			0x3B0

;internal system variables
#define MSCNTL        	0x3B1
#define MSCNTH        	0x3B2
#define TIXCNTL			0x3B3
#define TIXCNTH			0x3B4

#define WAVEHIL			0x3B5
#define WAVEHIH			0x3B6

#define LEDAUTO         0x3B7 	;0=LED_AUTO(default), 1=LED_OFF, 2=LED_ON
#define VARLOW          0x3B8   ;LowByte parameter storage of latest VAR
#define BAKTIBPTR		0x3B9	;pointer actual entry in BAKTIB
#define FCARRYL			0x3BA	;Forth Carry word (shifted,over,under)
#define FCARRYH			0x3BB

#define USYMBHEADL      0x3BC   ;count byte of latest valid entry
#define USYMBHEADH      0x3BD   ;updated by SEMIS, VAR, CONST
#define COPLO           0x3BE   ;code compiler pointer LOW byte
#define COPHI           0x3BF   ;code compiler pointer HIGH Byte
#define DELTACFLO       0x3C0   ;Delta actual code pointer n Flash and
#define DELTACFHI       0x3C1   ;it's mirror in CBUF(used by CBurn)
								;SYMP points to count byte of latest entry
#define STARTCOPL       0x3C2   ;start address of actual page in Flash
#define STARTCOPH       0x3C3
#define PAD             0x3C4	;sendWord temporary storage, filling upwards
								;max 8 Bytes
#define RETURNSTACK     0x444   ;filling downwards, pointer=SPH,SPL,116 bytes
#define DATASTACK       0x4B2	;filling downwards, 108 bytes = 54 entries

#define USBRXHEADL      0x4BA
#define USBRXHEADH      0x4BB
#define USBRXTAILL      0x4BC
#define USBRXTAILH      0x4BD
#define US1RXTAIL       0x4BE
#define US1RXHEAD       0x4BF

;UP INIEP  parameters
#define EP_NUM 			0x4C0       ;EP NUM: 0-6
#define EP_CONFIG0		0x4C1		;<--EPn_CFG0
#define EP_CONFIG1  	0x4C2		;<--EPn_CFG1

;Variables for SETUP packet
#define SU_R_T	 		0x4C3 		;bmRequestType	//byte
#define SU_REQ	 		0x4C4 		;bRequest 		//word
#define SU_VAL	 		0x4C6		;wValue 		//word
#define SU_IND	 		0x4C8 		;wIndex 		//word
#define SU_LEN	  		0x4CA		;wLength 		//byte??
;0x4CB...0x4CD reserved for future use
;global variables for endpoints
#define EP1_HEAD		0x4CE
#define EP1_TAIL		0x4CF
;EP3 only used with CDC_CLASS
#define EP3_CNT			0x4D0       ;number of data bytes to be transmitted
;storage buffer for endpoints (secondary storage, not USB FIFO buffer)       
#define EP3_BUF			0x4D1   ;16 byte buffer for notification data (to USB host)
								;in practice not used (under Windows at least)
#define EP2_BUF			0x500   ;3 pages buffer for received data (via USB)     
#define EP2_BUFTOP		0x800
#define EP2_SIZE		HIGH(EP2_BUFTOP)-HIGH(EP2_BUF)  ;number of pages

#define EP1_BUF			0x800	;1 page buffer for transmitted data (via USB)
#define EP1_BUFTOP		0x900	;exclusively first 64 bytes used

#define	INIMAX			0x900	;top of initial memory clearing

#define US1RXBUF        0x900    ;cyclic filling upwards,256 Bytes
#define US1RXBUFTOP     0xA00

#define CBUF            0xA00   ;256 bytes regulary montage buffer for Code
#define CBUFTOP         0xB00 	; = 2 Flash pages
#define SRAMTOP         0xB00

#endif

;--------------------------------------------------------------------

;INTERNAL EEPROM !
;leave bytes 0..3 emnpty as precaution 
#define XAUTO           4 ;(+5,6,7)	;AUTIOEXE vector
#define DEFNUMB			14			;startup number base (virgin=decimal)
#define USERSYMBTAB     16       	;rises up to INTEEP

#if (CPU==3244)
#define	VENDORIDL		8			;2 bytes, Little Endian
#define VENDORIDH		9
#define PRODUCTIDL		10			;2 bytes, Little Endian
#define PRODUCTIDH		11
#endif
;--------------------------------------------------------------------

#define		CRR             0xD    ;Cariage Return Character
#define     LFF             0xA    ;Line Feed Character
#define     BKSP            0x8    ;Backspace
#define    	HTAB            0x9
#define  	ESC				0x1B
#define     SPACE           0x20
#define     QUEST           0x3F   ;question mark
#define     BACKSLASH       0x5C
#define 	CTRL_A			1
#define 	CTRL_B			2
#define 	CTRL_C			3
#define 	CTRL_K			0xB		;KEY and RX1 terminator
#define 	CTRL_R			0x12	;MS terminator
#define 	CTRL_S			0x13	;background .S


#define     CONSTATTRIB       4      ;Constant Attribute Flag in countByte
#define     m_CONSTATTRIB     0x10
#define     VARATTRIB         5      ;Variable Attribute Flag in countByte
#define     m_VARATTRIB       0x20
#define     IMMEDIATE         6      ;flags in count byte
#define   	m_IMMEDIATE       0x40
#define     COMPO             7
#define     m_COMPO           0x80

#define		LEDTIME           3    	;x100 milliseconds = ca.300 ms

#ifdef SPEED_18M
;for 18,432 MHz crystal:
#define    	BAUD192		59  	;19200 Baud
#define    	BAUD384     29 		;38400 Baud
#define    	BAUD576      19    	;57600 Baud
#define    	BAUD115      9     	;115200 Baud
#define    	MSADJ        (256-72) ;timer=clock/256, counts up until overflow
#endif

#ifdef SPEED_16M
;for 16MHz crystal:
#define    	PLLPRE		1<<PINDIV  ;PLL prescaler Bit4 (ATmega32U4 only)
#define    	BAUD192     51     	;19200 Baud
#define    	BAUD384     25     	;38400 Baud
#define	   	BAUD115		16		;117600 Baud w.U2X flag set (Arduino Uno)
#define    	MSADJ       (256-62)  ;timer=clock/256
#endif                        

#ifdef SPEED_14M
;for 14,7456 MHz crystal:
#define    	BAUD192     47    	;19200 Baud
#define    	BAUD384     23    	;38400 Baud
#define    	BAUD576     15     	;115200 Baud
#define    	BAUD115     7     	;115200 Baud
#define    	MSADJ       (256-230) ;timer=clock/64, counts up until overflow
#endif 

#ifdef SPEED_11M
;for 11.059MHz crystal:
#define    	BAUD192     35		;19200 Baud
#define    	BAUD324		17		;38400 Baud
#define    	BAUD576		11		;57600 Baud
#define    	MSADJ       (256-173) ;timer=clock/64, counts up until overflow
#endif                  

#ifdef SPEED_7M
;for 7.372MHz crystal: HIvalues for 7.737MHz CPU clock, else for 921kHz 
#define    	BAUD192     2    ;init CPU speed=921kHz: 19200 Baud
#define    	BAUDHI192   23   ;init CPU speed=7.37MHz: 19200 Baud
#define    	BAUD576     0    ;init CPU speed=921kHz: 19200 Baud
#define    	BAUDHI576   7   ;init CPU speed=7.37MHz: 19200 Baud
#define    	MSADJ       (256-115) ;timer=clock/64, counts up until overflow
#define    	MSADJHI     (256-115) ;timer=clock/8, counts up until overflow
#endif                  

#ifdef SPEED_1M8
;for 1.8432MHz crystal: HIvalues for 1.8432MHz CPU clock, else for 921kHz
#define    	BAUD192     2    ;19200 Baud
#define    	BAUDHI192   5    ;19200 Baud
#define    	BAUD576     0    ;57600 Baud
#define    	BAUDHI576   1    ;57600 Baud
#define    	MSADJ       (256-115) ;timer=clock/16, counts up until overflow
#define    	MSADJHI     (256-230) ;timer=clock/8, counts up until overflow
#endif    

#define     MEMERR     		0     ;page limit overrun
#define     m_MEMERR        1
#define     PARAMERR        1     ;invalid parameter (number or name)
#define     m_PARAMERR      2
#define     STRTOKERR       2     ;invalid token by string
#define     m_STRTOKERR     4
#define     STACKERR        3     ;Stack underflow
#define     m_STACKERR      8
#define     RUNERR          4     ;Runtime error
#define     m_RUNERR        0x10
#define     ABORTED         5     ;ABORT aufgerufen
#define     m_ABORTED       0x20
#define     COMPONLY        6  ;"Compile Only" Wort interpretativ gerufen
#define     m_COMPONLY      0x40
#define     SYNTXERR        7     ;symbol table error
#define		m_SYNTXERR      0x80


#if ((CPU==168) || (CPU==328))
#define LED         6       ;PortD
#define ENC0PIN     5       ;PortD  count direction sensing ENCODE0
#define PMO1       	1       ;PortB  TimerOC1A
#define PMO2        3       ;PortD  TimerOC2A
#endif
#if ((CPU==644) || (CPU==1284))
#define LED         0       ;PortB
#define ENC0PIN     1       ;PortB 	count direction sensing ENCODE0
#define ENCXPIN     3       ;PortB 	count direction sensing ENCODEX
#define PMO1       	5       ;PortD  TimerOC1A
#define PMO2        7       ;PortD  TimerOC2
#endif
#if (CPU==32)
#define LED         0       ;PortB
#define ENC0PIN     4       ;PortD 	count direction sensing ENCODE0
#define ENCXPIN     7       ;PortB 	count direction sensing ENCODEX
#define PMO1       	5     	;PortB  TimerOC1A
#define PMO2       	6       ;PortC  TimerOC2A
#endif

#if (CPU==3244)
#define LED         6       ;PortD
#define TXLED		5       ;PortD	;LEONARDO onboard
#define ENC0PIN     4       ;PortD 	count direction sensing ENCODE0
#define ENCXPIN     5       ;PortD 	count direction sensing ENCODEX
#define PMO1       	6     	;PortB  TimerOC1A
#define PMO3       	6       ;PortC  TimerOC3A

;Constants for endpoints
#define EP0_CFG0	0x00		;CONTROL,OUT
#define EP0_CFG1	0x00		;8 bytes,1 bank	

;EP1 = IN EP (PC <- Device)
#define EP1_CFG0	0x81		;BULK,IN
#define EP1_CFG1	0x30		;64 bytes,1 bank	

;EP2 = OUT EP (PC -> Device)
#define EP2_CFG0	0x80		;BULK,OUT
#define EP2_CFG1	0x30		;64 bytes,1 bank	

;EP3 only used with CDC_CLASS
#define EP3_CFG0	0xC1		;INTERRUPT,IN
#define EP3_CFG1	0x10		;16 bytes,1 bank	

;little endian:
#define VIDDEFL			0x41
#define VIDDEFH			0x23

  #ifdef LEONARDO
#define PIDDEFL			0x36	;default Arduino Leonardo
  #else
#define PIDDEFL			0x37	;default Arduino Micro
  #endif
#define PIDDEFH			0x00
#endif ;(CPU==3244)



