;***************************************************************************
;* A P P L I C A T I O N   N O T E   F O R   T H E   A V R   F A M I L Y
;* 
;* Number		        :AVR000
;* File Name		    :"m32def.inc"
;* Title		        :Register/Bit Definitions for the ATmega32
;* Date                 :99.08.25
;* Version              :1.00
;* Support E-mail	    :avr@atmel.no
;* Target MCU		    :ATmega32
;*
;* DESCRIPTION
;* When including this file in the assembly program file, all I/O register	
;* names and I/O register bit names appearing in the data book can be used.
;* In addition, the six registers forming the three data pointers X, Y and
;* Z have been assigned names XL - ZH. Highest RAM address for Internal 
;* SRAM is also defined 
;*
;* The Register names are represented by their hexadecimal address.
;* 
;* The Register Bit names are represented by their bit number (0-7).
;* 
;* Please observe the difference in using the bit names with instructions
;* such as "sbr"/"cbr" (set/clear bit in register) and "sbrs"/"sbrc" 
;* (skip if bit in register set/cleared). The following example illustrates
;* this:
;* 
;* in	r16,PORTB		;read PORTB latch
;* sbr	r16,(1<<PB6)+(1<<PB5)	;set PB6 and PB5 (use masks, not bit#)
;* out  PORTB,r16		;output to PORTB
;*
;* in	r16,TIFR		;read the Timer Interrupt Flag Register
;* sbrc	r16,TOV0		;test the overflow flag (use bit#)
;* rjmp	TOV0_is_set		;jump if set
;* ...				;otherwise do something else
;***************************************************************************

;***** Specify Device
.device ATmega32

;***** I/O Register Definitions
.equ    SREG    =0x3f
.equ    SPH         =0x3e
.equ    SPL         =0x3d
.equ    OCR0    =0x3c
.equ    GIMSK   =0x3b        	; For compatibility, keep both names until further
.equ    GICR    =0x3b       	; new name for GIMSK
.equ    GIFR    =0x3a
.equ    TIMSK   =0x39
.equ    TIFR    =0x38
.equ    SPMCR   =0x37
.equ	SPMCSR	=0x37			; For compatibility,
.equ    TWCR    =0x36
.equ    MCUCR   =0x35
.equ    MCUSR   =0x34        	; For compatibility,
.equ    MCUCSR  =0x34        	; keep both names until further
.equ    TCCR0   =0x33
.equ    TCNT0   =0x32
.equ    OSCCAL  =0x31
.equ    SFIOR   =0x30
.equ    TCCR1A  =0x2f
.equ    TCCR1B  =0x2e
.equ    TCNT1H  =0x2d
.equ    TCNT1L  =0x2c
.equ    OCR1AH  =0x2b
.equ    OCR1AL  =0x2a
.equ    OCR1BH  =0x29
.equ    OCR1BL  =0x28
.equ    ICR1H   =0x27
.equ    ICR1L   =0x26
.equ    TCCR2   =0x25
.equ    TCNT2   =0x24
.equ    OCR2    =0x23
.equ    ASSR    =0x22
.equ    WDTCR   =0x21
;.equ    UBRRH   =0x20            ;  Note! UCSRC equals UBRRH
.equ    EEARH   =0x1f
.equ    EEARL   =0x1e
.equ    EEDR    =0x1d
.equ    EECR    =0x1c
.equ    PORTA   =0x1b
.equ    DDRA    =0x1a
.equ    PINA    =0x19
.equ    PORTB   =0x18
.equ    DDRB    =0x17
.equ    PINB    =0x16
.equ    PORTC   =0x15
.equ    DDRC    =0x14
.equ    PINC    =0x13
.equ    PORTD   =0x12
.equ    DDRD    =0x11
.equ    PIND    =0x10
.equ    SPDR    =0x0f
.equ    SPSR    =0x0e
.equ    SPCR    =0x0d
.equ    UDR     =0x0c
.equ    UCSRA   =0x0b
.equ    USR	=0x0b		;for compatibility with old code
.equ    UCSRB   =0x0a
.equ    UCR	=0x0a		;for compatibility with old code
.equ    UCSRC   =0x20            ;  Note! UCSRC equals UBRRH
.equ    UBRRH   =0x20
.equ    UBRRL   =0x09
.equ    ACSR    =0x08
.equ    ADMUX   =0x07
.equ    ADCSR   =0x06
.equ    ADCH    =0x05
.equ    ADCL    =0x04
.equ    TWDR    =0x03
.equ    TWAR    =0x02
.equ    TWSR    =0x01
.equ    TWBR    =0x00



;***** Bit Definitions
;GIMSK
.equ	INT1	=7
.equ	INT0	=6
.equ	INT2	=5
.equ	IVSEL	=1		; interrupt vector select
.equ	IVCE	=0		; interrupt vector change enable

;GIFR
.equ	INTF1	=7
.equ	INTF0	=6
.equ	INTF2	=5

;TIMSK
.equ    TOIE0   =0
.equ    OCIE0   =1
.equ    TOIE1   =2
.equ    OCIE1B  =3
.equ    OCIE1A  =4
.equ    TICIE1  =5
.equ    TOIE2   =6
.equ    OCIE2   =7

;TIFR
.equ    TOV0    =0
.equ    OCF0    =1
.equ    TOV1    =2
.equ    OCF1B   =3
.equ    OCF1A   =4
.equ    ICF1    =5
.equ    TOV2    =6
.equ    OCF2    =7

;SPMCR
.equ	SPMIE	=7
.equ	ASB	=6
.equ	RWWSB	=6	; for compatibility Read-While-Write Section Busy
.equ	ASRE	=4
.equ	RWWSRE	=4	; for compatibility Read-While-Write section read enable
.equ	BLBSET	=3
.equ	PGWRT	=2
.equ	PGERS	=1
.equ	SPMEN	=0
.equ	SELFPRGEN = 0	; for compatibility

;MCUCR
.equ    SE      =7
.equ    SM2     =6
.equ    SM1     =5
.equ    SM0     =4
.equ    ISC11   =3
.equ    ISC10   =2
.equ    ISC01   =1
.equ    ISC00   =0

;MCUCSR
.equ	JTD     =7	
.equ    ISC2    =6
.equ    EIH     =5
.equ    JTRF    =4	
.equ    WDRF    =3
.equ    BORF    =2
.equ    EXTRF   =1
.equ    PORF    =0

;TCCR0
.equ    FOC0    =7
.equ    PWM0    =6
.equ	COM01	=5
.equ	COM00	=4
.equ	CTC0	=3
.equ	CS02	=2
.equ	CS01	=1
.equ	CS00	=0

;TCCR1A
.equ	COM1A1	=7
.equ	COM1A0	=6
.equ	COM1B1	=5
.equ	COM1B0	=4
.equ	FOC1A	=3
.equ	FOC1B	=2
.equ    PWM11   =1              ;compatibility
.equ    WGM11   =1
.equ    PWM10   =0              ;compatibility
.equ    WGM10   =0

;TCCR1B
.equ	ICNC1	=7
.equ	ICES1	=6
.equ    CTC11   =4              ;compatiblity
.equ    WGM13   =4
.equ	CTC10	=3
.equ    CTC1    =3       ; Obsolete - Included for backward compatibility
.equ    WGM12   =3
.equ    CS12    =2
.equ	CS11	=1
.equ	CS10	=0

;TCCR2
.equ	FOC2	=7
.equ    PWM2    =6
.equ    WGM20   =6              ;compatibility
.equ    COM21   =5
.equ    COM20   =4
.equ    CTC2    =3
.equ    WGM21   =3              ;compatibility
.equ    CS22    =2
.equ    CS21    =1
.equ    CS20    =0

;SFIOR
.equ    RPDD    =7
.equ    RPDC    =6
.equ    RPDB    =5
.equ    RPDA    =4
.equ    ACME    =3
.equ    PUD     =2
.equ	PSR2	=1
.equ	PSR10	=0

;WDTCR
.equ	WDTOE	=4
.equ	WDE	=3
.equ	WDP2	=2
.equ	WDP1	=1
.equ	WDP0	=0

;EECR
.equ    EERIE   =3
.equ	EEMWE	=2
.equ	EEMPE	= 2	;for compatibility EEPROM Master Write Enable
.equ	EEWE	=1
.equ	EEPE	=1	;for compatibility  EEPROM Write Enable
.equ	EERE	=0

;PORTA
.equ	PA7	=7
.equ	PA6	=6
.equ	PA5	=5
.equ	PA4	=4
.equ	PA3	=3
.equ	PA2	=2
.equ	PA1	=1
.equ	PA0	=0

;DDRA
.equ	DDA7	=7
.equ	DDA6	=6
.equ	DDA5	=5
.equ	DDA4	=4
.equ	DDA3	=3
.equ	DDA2	=2
.equ	DDA1	=1
.equ	DDA0	=0

;PINA
.equ	PINA7	=7
.equ	PINA6	=6
.equ	PINA5	=5
.equ	PINA4	=4
.equ	PINA3	=3
.equ	PINA2	=2
.equ	PINA1	=1
.equ	PINA0	=0

;PORTB
.equ	PB7	=7
.equ	PB6	=6
.equ	PB5	=5
.equ	PB4	=4
.equ	PB3	=3
.equ	PB2	=2
.equ	PB1	=1
.equ	PB0	=0

;DDRB
.equ	DDB7	=7
.equ	DDB6	=6
.equ	DDB5	=5
.equ	DDB4	=4
.equ	DDB3	=3
.equ	DDB2	=2
.equ	DDB1	=1
.equ	DDB0	=0

;PINB
.equ	PINB7	=7
.equ	PINB6	=6
.equ	PINB5	=5
.equ	PINB4	=4
.equ	PINB3	=3
.equ	PINB2	=2
.equ	PINB1	=1
.equ	PINB0	=0

;PORTC
.equ	PC7	=7
.equ	PC6	=6
.equ	PC5	=5
.equ	PC4	=4
.equ	PC3	=3
.equ	PC2	=2
.equ	PC1	=1
.equ	PC0	=0

;DDRC
.equ	DDC7	=7
.equ	DDC6	=6
.equ	DDC5	=5
.equ	DDC4	=4
.equ	DDC3	=3
.equ	DDC2	=2
.equ	DDC1	=1
.equ	DDC0	=0

;PINC
.equ	PINC7	=7
.equ	PINC6	=6
.equ	PINC5	=5
.equ	PINC4	=4
.equ	PINC3	=3
.equ	PINC2	=2
.equ	PINC1	=1
.equ	PINC0	=0

;PORTD
.equ	PD7	=7
.equ	PD6	=6
.equ	PD5	=5
.equ	PD4	=4
.equ	PD3	=3
.equ	PD2	=2
.equ	PD1	=1
.equ	PD0	=0

;DDRD
.equ	DDD7	=7
.equ	DDD6	=6
.equ	DDD5	=5
.equ	DDD4	=4
.equ	DDD3	=3
.equ	DDD2	=2
.equ	DDD1	=1
.equ	DDD0	=0

;PIND
.equ	PIND7	=7
.equ	PIND6	=6
.equ	PIND5	=5
.equ	PIND4	=4
.equ	PIND3	=3
.equ	PIND2	=2
.equ	PIND1	=1
.equ	PIND0	=0

;UCSRA
.equ	RXC	=7
.equ	TXC	=6
.equ	UDRE	=5
.equ	FE	=4
.equ    OVR     =3           	; compatibility name 
.equ	DOR	=3
.equ	PE	=2
.equ	U2X	=1
.equ	U2X0	=1  		; compatibility name
.equ	MPCM	=0

;UCSRB
.equ	RXCIE	=7
.equ	TXCIE	=6
.equ	UDRIE	=5
.equ	RXEN	=4
.equ	TXEN	=3
.equ	CHR9	=2		; old name kept for compatibilty
.equ	UCSZ2	=2
.equ	RXB8	=1
.equ	TXB8	=0

;UCSRC
.equ	URSEL	=7
.equ	UMSEL	=6
.equ	UPM1	=5
.equ	UPM0	=4
.equ	USBS	=3
.equ	UCSZ1	=2
.equ	UCSZ0	=1
.equ	UCPOL	=0
		
;SPCR
.equ	SPIE	=7
.equ	SPE	=6
.equ	DORD	=5
.equ	MSTR	=4
.equ	CPOL	=3
.equ	CPHA	=2
.equ	SPR1	=1
.equ	SPR0	=0

;SPSR
.equ	SPIF	=7
.equ	WCOL	=6
.equ	SPI2X	=0

;ACSR
.equ	ACD	=7
.equ    ACBG    =6
.equ	ACO	=5
.equ	ACI	=4
.equ	ACIE	=3
.equ	ACIC	=2
.equ	ACIS1	=1
.equ	ACIS0	=0

;ADMUX
.equ    REFS1   =7
.equ    REFS0   =6
.equ    ADLAR   =5
.equ    MUX4    =4
.equ    MUX3    =3
.equ    MUX2    =2
.equ    MUX1    =1
.equ    MUX0    =0

;ADCSR
.equ    ADEN    =7
.equ    ADSC    =6
.equ    ADFR    =5
.equ    ADIF    =4
.equ    ADIE    =3
.equ    ADPS2   =2
.equ    ADPS1   =1
.equ    ADPS0   =0

; TWCR
.equ    TWINT   =7
.equ    TWEA    =6
.equ    TWSTA   =5
.equ    TWSTO   =4
.equ    TWWC    =3
.equ    TWEN    =2
.equ    TWI_TST =1  ;Present in core test mode only. Write Only.
.equ    TWIE    =0

; TWAR
.equ    TWGCE   =0

;ASSR
.equ    AS2     =3
.equ    TCN2UB  =2
.equ    OCR2UB  =1
.equ    TCR2UB  =0

.def	XL	=r26
.def	XH	=r27
.def	YL	=r28
.def	YH	=r29
.def	ZL	=r30
.def	ZH	=r31

.equ    FLASHEND        =0x3FFF
.equ    E2END       =0x3FF
.equ    RAMEND      =0x85F

			;  byte groups
			;  /\/--\/--\/--\ 
.equ    SMALLBOOTSTART  =0b11111100000000  ;(0x3F00) smallest boot block is 256W
.equ    SECONDBOOTSTART =0b11111000000000  ;(0x3E00) 2'nd boot block size is 512W
.equ    THIRDBOOTSTART  =0b11110000000000  ;(0x3C00) third boot block size is 1KW
.equ    LARGEBOOTSTART  =0b11100000000000  ;(0x3800) largest boot block is 2KW
.equ 	BOOTSTART	=THIRDBOOTSTART  ;OBSOLETE!!! kept for compatibility
.equ	PAGESIZE	=64     ;number of WORDS in a page


.equ    INT0addr=0x002   ; External Interrupt0 Vector Address
.equ    INT1addr=0x004   ; External Interrupt1 Vector Address
.equ    INT2addr=0x006   ; External Interrupt2 Vector Address
.equ    OC2addr =0x008   ; Output Compare2 Interrupt Vector Address
.equ    OVF2addr=0x00a   ; Overflow2 Interrupt Vector Address
.equ    ICP1addr=0x00c   ; Input Capture1 Interrupt Vector Address
.equ    OC1Aaddr=0x00e   ; Output Compare1A Interrupt Vector Address
.equ    OC1Baddr=0x010   ; Output Compare1B Interrupt Vector Address
.equ    OVF1addr=0x012   ; Overflow1 Interrupt Vector Address
.equ    OC0addr =0x014   ; Output Compare0 Interrupt Vector Address
.equ    OVF0addr=0x016   ; Overflow0 Interrupt Vector Address
.equ    SPIaddr =0x018   ; SPI Interrupt Vector Address
.equ    URXCaddr=0x01a   ; USART Receive Complete Interrupt Vector Address
.equ    UDREaddr=0x01c   ; USART Data Register Empty Interrupt Vector Address
.equ    UTXCaddr=0x01e   ; USART Transmit Complete Interrupt Vector Address
.equ    ADCCaddr=0x020   ; ADC Interrupt Vector Address
.equ    ERDYaddr=0x022   ; EEPROM Interrupt Vector Address
.equ    ACIaddr =0x024   ; Analog Comparator Interrupt Vector Address
.equ    TWSIaddr=0x026   ; Irq. vector address for Two-Wire Interface
.equ    SPMRaddr=0x028   ; Store Program Memory Ready Interrupt Vector Address
.equ    VECT_SIZE=0x02A


